from setuptools import setup, find_packages

setup(name='pyktug-guilleeh90',
		version='0.0.1',
		description='Data analysis in TUG test for Kinect v2',
		license='MIT',
		author='Guillermo Díaz',
		author_email='guillermodiazsm@gmail.com',
		url='https://github.com/guilleeh90',
		packages=find_packages(),
		classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
		],
		python_requires='>=3.6',
		)
